summaryrefslogtreecommitdiffstats
path: root/karbon/core/vcursor.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit04766b207afba7961d4d802313e426f5a2fbef63 (patch)
treec888ea1027c793e2d0386a7e5a1a0cd077b03cb3 /karbon/core/vcursor.h
parentb6edfe41c9395f2e20784cbf0e630af6426950a3 (diff)
downloadkoffice-04766b207afba7961d4d802313e426f5a2fbef63.tar.gz
koffice-04766b207afba7961d4d802313e426f5a2fbef63.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'karbon/core/vcursor.h')
-rw-r--r--karbon/core/vcursor.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/karbon/core/vcursor.h b/karbon/core/vcursor.h
index 90ab1673..ccb4a36f 100644
--- a/karbon/core/vcursor.h
+++ b/karbon/core/vcursor.h
@@ -27,7 +27,7 @@
* A helper class for easily creating cursors from XPMs.
*
* One can create a predefined unthemed cursor or create a cursor from two given XMPs,
* the cursor bitmap and the cursor tqmask.
*/
class KARBONBASE_EXPORT VCursor
{
@@ -53,7 +53,7 @@ public:
* Creates a cursor from two specified XPM images.
* This is only a wrapper function for a TQCursor ctor.
*/
- static TQCursor createCursor( const char * bitmap[], const char * tqmask[], int hotX = -1, int hotY = -1 );
+ static TQCursor createCursor( const char * bitmap[], const char * mask[], int hotX = -1, int hotY = -1 );
/** crosshair cursor */
static TQCursor crossHair();
@@ -27,7 +27,7 @@
*
* One can create a predefined unthemed cursor or create a cursor from two given XMPs,
-* the cursor bitmap and the cursor tqmask.
+* the cursor bitmap and the cursor mask.
*/
class KARBONBASE_EXPORT VCursor